% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/RcppExports.R
\name{stoch_vol}
\alias{stoch_vol}
\title{Stochastic Volatility}
\usage{
stoch_vol(y, h, sigma, h_init)
}
\arguments{
\item{y}{a \eqn{T \times 1} vector containing the time series.}

\item{h}{a \eqn{T \times 1} vector of log-volatilities.}

\item{sigma}{a numeric of the variance of the log-volatilites.}

\item{h_init}{a numeric of the initial state of log-volatilities.}
}
\value{
A vector of log-volatility draws.
}
\description{
Produces a draw of log-volatilities.
}
\details{
The function produces a posterior draw of the log-volatility \eqn{h} for the model
\deqn{y_{t} = e^{\frac{1}{2}h_t} \epsilon_{t},}
where \eqn{\epsilon_t \sim N(0, 1)} and \eqn{h_t} is assumed to evolve according to a random walk
\deqn{h_t = h_{t - 1} + u_t,}
with \eqn{u_t \sim N(0, \sigma^2)}.

The implementation follows the algorithm of Kim, Shephard and Chip (1998) and performs the
following steps:
\enumerate{
  \item Perform the transformation \eqn{y_t^* = ln(y_t^2 + 0.0001)}.
  \item Obtain a sample from the seven-component normal mixture for
  approximating the log-\eqn{\chi_1^2} distribution.
  \item Obtain a draw of log-volatilities.
}

The implementation follows the code provided on the website to the textbook by Chan, Koop, Poirier, and Tobias (2019).
}
\examples{
data("us_macrodata")
y <- us_macrodata[, "r"]

# Initialise log-volatilites
h_init <- log(var(y))
h <- rep(h_init, length(y))

# Obtain draw
stoch_vol(y - mean(y), h, .05, h_init)

}
\references{
Chan, J., Koop, G., Poirier, D. J., & Tobias J. L. (2019). \emph{Bayesian econometric methods}
(2nd ed.). Cambridge: Cambridge University Press.

Kim, S., Shephard, N., & Chib, S. (1998). Stochastic volatility. Likelihood inference and comparison
with ARCH models. \emph{Review of Economic Studies 65}(3), 361--393. \doi{10.1111/1467-937X.00050}
}
